#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hasql-pool
version:              0.5.2.2
visibility:           public
id:                   hasql-pool-0.5.2.2-7rq15M8MzgQ1JOsHyCK1gI
key:                  hasql-pool-0.5.2.2-7rq15M8MzgQ1JOsHyCK1gI
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/hasql-pool 
synopsis:             A pool of connections for Hasql
category:             Hasql, Database, PostgreSQL
abi:                  24e7cccc2962f73077f83e253da1fa6a
exposed:              True
exposed-modules:      Hasql.Pool
hidden-modules:       Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.5.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.5.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hasql-pool-0.5.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hasql-pool
hs-libraries:         HShasql-pool-0.5.2.2-7rq15M8MzgQ1JOsHyCK1gI
depends:
    base-prelude-1.6.1.1-D2kQqMusnHdEzaJTSBYmnI
    hasql-1.5.0.5-93ZXSGavr0y1G6vZVD81kw
    resource-pool-0.2.3.2-1D8B1j5bhgn235Fzsnu0Pc time-1.12.2

haddock-interfaces:   /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html:         /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

